#
# spec file for package noisetorch
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           noisetorch
Version:        0.12.2
Release:        2.6
Summary:        Real-time microphone noise suppression on Linux
License:        GPL-3.0-or-later
URL:            https://github.com/NoiseTorch/NoiseTorch
# osc service disabledrun
Source0:        NoiseTorch-%{version}.tar.gz
# osc service disabledrun
Source1:        vendor.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  git-core
BuildRequires:  hicolor-icon-theme
BuildRequires:  golang(API) = 1.18

%description
NoiseTorch is an easy to use open source application for Linux with PulseAudio.
It creates a virtual microphone that suppresses noise, in any application. Use
whichever conferencing or VOIP application you like and simply select the
NoiseTorch Virtual Microphone as input to torch the sound of your mechanical
keyboard, computer fans, trains and the likes.

%prep
%autosetup -p1 -n NoiseTorch-%{version} -a1

%build
pushd c/ladspa
%make_build
ldd rnnoise_ladspa.so
popd
go generate
# -tags release would enable the auto-updater (update.go)

CGO_ENABLED=0 GOOS=linux go build \
%ifnarch ppc64
    -buildmode=pie \
%endif
    -a -ldflags '-w -X main.version=%{version} -X main.distribution=rpm' .

%install
install -D -m 644 assets/icon/noisetorch.png %{buildroot}/%{_datadir}/icons/hicolor/256x256/apps/noisetorch.png
install -D -m 644 assets/noisetorch.desktop %{buildroot}/%{_datadir}/applications/noisetorch.desktop
install -D -m 755 noisetorch %{buildroot}/%{_bindir}/noisetorch

%files
%license LICENSE
%doc README.md
%caps(cap_sys_resource+ep) %{_bindir}/noisetorch
%{_datadir}/applications/noisetorch.desktop
%{_datadir}/icons/hicolor/256x256/apps/noisetorch.png

%changelog
* Mon Jul  4 2022 Dirk Müller <dmueller@suse.com>
- use go1.18
* Mon Jun 20 2022 mvetter@suse.com
- Update to version 0.12.2:
  * Preparing v0.12.2
  * fix(update): prefer TrimLeft to slice operator when removing prefixes
  * fix(update): strip 'v' from version string
  * Preparing v0.12.1
  * chore: minor refactoring
  * chore(views): Reimplement views using slices
  * Update .github/ISSUE_TEMPLATE/bug_report.md
  * Update issue templates
  * Improve code that reads the latest release from GitHub
  * fix(updates): Handle other possible errors in getLatestRelease()
  * Add noisetorch/pulseaudio to the vendor folder.
  * Update vendor dir for noisetorch/pulseaudio.
  * Update go.mod, go.sum to noisetorch/pulseaudio.
  * Update imports to point to noisetorch/pulseaudio.
  * Install instructions for source build
  * fix(updates): Fix crash when no internet connection
  * Bump david-a-wheeler/flawfinder from 2.0.19.pre.alpha1 to 2.0.19
  * fix(dependabot): correct dir for submods & actions
  * Bump github.com/BurntSushi/toml from 0.4.1 to 1.1.0
  * README.md
  * Update README.md
  * badge rounded edges
  * Readme Modifications
* Wed Jun 15 2022 rombert@apache.org
- Update to version v0.12.0:
  * notice about security incident and audit
  * Update README.md
  * Update README.md
  * Update README.md
  * Update README.md
  * feat(updater): update from github releases
  * chore(updater): add bland/semver module
  * Distribute not in if statement for clarity.
  * When filter is selected but no device is selected show unconfigured.
  * Remove unnecessary parenthesis.
  * when no mic is connected and mic is selected to filter, don't show load
* Fri Apr 22 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.11.5:
  * Makefile: enable -trimpath
  * modules: Append original device name to virtual microphone
  * Makefile: use $(MAKE) instead of directly using make
  * Chore: Upgrade nucular GUI dependency
  * Chore: Upgrade toml dependency
- Do not use -buildmode=pie in ppc64 where it's not supported.
* Fri Oct  8 2021 Dirk Müller <dmueller@suse.com>
- Update to version 0.11.4:
  * Pulseaudio: Don't crash on receiving longer-than-expected string message
  * Fix desktop icon
  * Add PipeWire support to README
  * UI: Add confirm screen for unload/reload when device in use
  * Handle non-semver versions in audio client gracefully-ish
  * pulseaudio: update module with fixed cookie lookup
  * CLI: Cleanup temp files on exit
  * c:ladspa: Fix linking with libm
  * Revert "Temporarily force clang if available"
- drop noisetorch-fix-ladspa-linking.patch (obsolete)
* Tue Aug  3 2021 Andreas Schwab <schwab@suse.de>
- Don't link statically
* Thu Jul 15 2021 Robert Munteanu <rombert@apache.org>
- Include the version and packaging information in the about screen
* Wed May 26 2021 Andreas Schneider <asn@cryptomilk.org>
- Fix linking of librnnoise.so
  adds noisetorch-fix-ladspa-linking.patch
* Tue May 25 2021 asn@cryptomilk.org
- Update to version 0.11.2:
  * https://github.com/lawl/NoiseTorch/releases/tag/0.11.2
  * https://github.com/lawl/NoiseTorch/releases/tag/0.11.1
  * https://github.com/lawl/NoiseTorch/releases/tag/0.11.0
* Mon May 17 2021 Dirk Müller <dmueller@suse.com>
- make noisetorch effective permissible cap_sys_resource (bsc#1184843)
* Mon May 17 2021 Dirk Müller <dmueller@suse.com>
- remove -tags release to avoid the auto-updater
* Sat Apr 24 2021 Dirk Müller <dmueller@suse.com>
- use buildmode=pie
* Mon Mar 29 2021 dmueller@suse.com
- Update to version 0.10.1:
  * Use -O2 for LADSPA module
  * Use go:embed instead of scripts/embedbinary.go
  * Update 'Special thanks to'
  * Update build instructions
  * Add information about potentially having to relog for PATH changes
  * Convert fmt print to log print
  * Fix unloading via CLI (-u)
  * Use 24-hour clock when adding timestamps to log file names. (#92)
  * Add warning if FS capabilities don't match process capabilities
  * Make sure we remove rlimit for unloading too
  * Require capabilities on startup
  * use different params for fixed latency devices to hopefully correct latency faster
  * Add -Wall, -Werr
  * Replace noise-suppression-for-voice with own implementation
  * Update README.md
  * remove more commented code (yuck)
  * remove commented out code
* Mon Jan  4 2021 Dirk Müller <dmueller@suse.com>
- Initial package (0.9.0)
